@@ -10,8 +10,10 @@ import (
 	"{{GOLANG_MODULE}}/internal/event"
 )
 
-var log = event.Log
-var conf = config.Conf()
+var (
+	log  = event.Logger()
+	conf = config.Conf()
+)
 
 const (
 	MySQL  = "mysql"
